seq/seq.hpp

The seq/seq.hpp header defines basic primitives for manipulating seqs.

#### Usage

#include <boost/preprocessor/seq/seq.hpp>

#### Contents

- BOOST_PP_SEQ_HEAD
- BOOST_PP_SEQ_NIL
- BOOST_PP_SEQ_TAIL

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)